library xappbase;

import 'package:flutter/material.dart';
import 'package:flutter_localizations/flutter_localizations.dart';

import 'screens/SettingsPage/SettingsPage.Controller.dart';
import 'screens/SampleForUI/sample_item_details_view.dart';

/// Classe Base dell'app da configurare.
class XAppBase extends StatelessWidget {
  const XAppBase({Key? key, this.settingsController, this.changeNotifier, this.initialRoute, this.tipoUI, this.tabs}) : super(key: key);

  final SettingsController? settingsController;
  final dynamic changeNotifier;
  final String? initialRoute;
  final String? tipoUI;
  final String? tabs;

  // ///Chiamalo dall'esterno per overridarlo
  // static void main() async {
  //   final settingsController = SettingsController(SettingsService());
  //   await settingsController.loadSettings();
  //   runApp(XAppBase(
  //     settingsController: settingsController,
  //   ));
  // }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: settingsController!,
      builder: (BuildContext context, Widget? child) {
        return MaterialApp(
          restorationScopeId: 'app',
          localizationsDelegates: const [
            GlobalMaterialLocalizations.delegate,
          ],
          supportedLocales: const [
            Locale('en', ''),
            Locale('it', ''),
          ],
          initialRoute: initialRoute,
          theme: ThemeData(),
          darkTheme: ThemeData.dark(),
          themeMode: settingsController!.themeMode,
          onGenerateRoute: (RouteSettings routeSettings) {
            return MaterialPageRoute<void>(
              settings: routeSettings,
              builder: (BuildContext context) {
                if (routeSettings.name!.startsWith("Sch")) {
                  TabController? tabController;
                  List<Widget>? tabs = List<Widget>.empty(growable: true);
                  return XfxScheda(
                    childrenOfTabViewer: [],
                    tabController: tabController,
                    tabs: tabs,
                  );
                } else {
                  return Container(
                    color: Colors.green,
                    height: 200,
                    width: 200,
                  );
                }
              },
            );
          },
          debugShowCheckedModeBanner: false,
        );
      },
    );
  }
}
